//
//  ListViewController.m
//  Shopping List
//
//  Created by Fandi on 12/05/13.
//  Copyright (c) 2013 Gopang Labs. All rights reserved.
//

#import "ListViewController.h"
#import "Item.h"
#import "AddItemViewController.h"

@interface ListViewController ()
@property NSMutableArray *items;
@end

@implementation ListViewController

- (void)controller:(AddItemViewController *)controller didSaveItemWithName:(NSString *)name andPrice:(float)price {
    // Create item
    Item *item = [Item createItemWithName:name andPrice:price];
    // Add item to data source
    [self.items addObject:item];
    // Add row to table view
    NSIndexPath *newIndexPath = [NSIndexPath indexPathForItem:([self.items count]- 1) inSection:0];
    [self.tableView insertRowsAtIndexPaths:@[newIndexPath] withRowAnimation:UITableViewRowAnimationNone];
    // Save item
    [self saveItems];
}

- (void)controller:(EditItemViewController *)controller didUpdateItem:(Item *)item {
    // Fetch item
    for (int i = 0; i < self.items.count; i++) {
        Item *anItem = [self.items objectAtIndex:i];
        if ([[anItem uuid] isEqualToString:item.uuid]) {
            // Update table view row
            NSIndexPath *indexPath = [NSIndexPath indexPathForItem:i inSection:0];
            [self.tableView reloadRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
        }
    }
    // Save item
    [self saveItems];
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
        self.title = @"Items";
        // Load Items
        [self loadItems];
    }
    return self;
}

- (void)loadItems {
    NSString *filePath = [self pathForItems];
    if ([[NSFileManager defaultManager] fileExistsAtPath:filePath]) {
        self.items = [NSKeyedUnarchiver unarchiveObjectWithFile:filePath];
    } else {
        self.items = [NSMutableArray array];
    }
}

- (NSString *)pathForItems {
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *document = [paths lastObject];
    return [document stringByAppendingPathComponent:@"items.plist"];
}

- (void)saveItems {
    NSString *filePath = [self pathForItems];
    [NSKeyedArchiver archiveRootObject:self.items toFile:filePath];
    // Post Notification
    [[NSNotificationCenter defaultCenter] postNotificationName:@"ShoppingListDidChangeNotification" object:nil];
}

- (void)addItem:(id)sender {
    NSLog(@"Button was tapped");
    // Initializa Add item controller
    AddItemViewController *addItemViewController = [[AddItemViewController alloc] init];
    // set delegate
    [addItemViewController setDelegate:self];
    // Present view controller
    [self presentViewController:addItemViewController animated:YES completion:nil];
}

- (void)editItems:(id)sender {
    [self.tableView setEditing:![self.tableView isEditing] animated:YES];
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self action:@selector(addItem:)];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemEdit target:self action:@selector(editItems:)];
    NSLog(@"Items > %@", self.items);
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    // Return the number of sections.
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return self.items.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    [tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:CellIdentifier];
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
    // Fetch Items
    Item *item = [self.items objectAtIndex:indexPath.row];
    // Configure the cell...
    cell.textLabel.text = item.name;
    cell.accessoryType = UITableViewCellAccessoryDetailDisclosureButton;
    // Show/Hide Checkmark
    if ([item inShoppingList]) {
        cell.imageView.image = [UIImage imageNamed:@"checkmark"];
    } else {
        cell.imageView.image = nil;
    }
    return cell;
}


// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    /*if ([indexPath row] == 1) {
        return NO;
    }*/
    return YES;
}



// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete item from items
        [self.items removeObjectAtIndex:indexPath.row];
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
        [self saveItems];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}


/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Navigation logic may go here. Create and push another view controller.
    /*
     <#DetailViewController#> *detailViewController = [[<#DetailViewController#> alloc] initWithNibName:@"<#Nib name#>" bundle:nil];
     // ...
     // Pass the selected object to the new view controller.
     [self.navigationController pushViewController:detailViewController animated:YES];
     */
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    // Fetch Item
    Item *item = [self.items objectAtIndex:indexPath.row];
    // Update item
    [item setInShoppingList:![item inShoppingList]];
    // Update cell
    UITableViewCell *cell = [tableView cellForRowAtIndexPath:indexPath];
    if ([item inShoppingList]) {
        cell.imageView.image = [UIImage imageNamed:@"checkmark.png"];
    } else {
        cell.imageView.image = nil;
    }
    [self saveItems];
}

- (void) tableView:(UITableView *)tableView accessoryButtonTappedForRowWithIndexPath:(NSIndexPath *)indexPath {
    // Fetch item
    Item *item = [self.items objectAtIndex:indexPath.row];
    // Initialize edit item
    EditItemViewController *editItemViewController = [[EditItemViewController alloc] initWithItem:item andDelegate:self];
    // Push view controller onto navigation stack
    [self.navigationController pushViewController:editItemViewController animated:YES];
}

@end
